#!/usr/bin/env python
#
# ORIGIN: ZACHTRONICS INDUSTRIES / WEST / ADVANCED GRAPHICS TECHNOLOGIES LABORATORY
# STABILITY: EXPERIMENTAL
#
# DEPENDENCY: Python 2.x <http://www.python.org/download/>
# DEPENDENCY: Python Imaging Library <http://www.pythonware.com/products/pil/>
#
# USAGE: python gfx_ichg_tool_alpha2.py image1.png image2.jpg ...

from __future__ import with_statement
import os.path
import PIL.Image as I
import sys

def convert_image(filename):
    new_name = os.path.splitext(filename)[0] + ".xml"
    image = I.open(filename)
    with open(new_name, 'w') as f:
        write_image(f, image)
    return True

def write_image(out, image):
    w, h = image.size
    data = image.convert('RGBA').getdata()
    out.write('<image width="{0}" height="{1}">\n'.format(w, h))
    for y in range(h):
        out.write('  <row>\n')
        for x in range(w):
            write_pixel(out, data[y * w + x])
        out.write('  </row>\n')
    out.write('</image>\n')
    
def write_pixel(out, pixel):
    r, g, b, a = pixel
    out.write('    <pixel>\n')
    out.write('      <red>{0}</red>\n'.format(float(r) / 255))
    out.write('      <green>{0}</green>\n'.format(float(g) / 255))
    out.write('      <blue>{0}</blue>\n'.format(float(b) / 255))
    out.write('      <alpha>{0}</alpha>\n'.format(float(a) / 255))
    out.write('    </pixel>\n')

# Entry point.
if __name__ == '__main__':
    files = sys.argv[1:]
    for f in files:
        convert_image(f)
